Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(608)

Unified Diff: runtime/vm/heap.h

Issue 187113003: Track external allocated memory for weak persistent handles. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 6 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/gc_marker.cc ('k') | runtime/vm/heap.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/heap.h
===================================================================
--- runtime/vm/heap.h (revision 33396)
+++ runtime/vm/heap.h (working copy)
@@ -102,6 +102,10 @@
return 0;
}
+ // Track external data.
+ void AllocateExternal(intptr_t size, Space space);
+ void FreeExternal(intptr_t size, Space space);
+
// Heap contains the specified address.
bool Contains(uword addr) const;
bool NewContains(uword addr) const;
@@ -162,9 +166,10 @@
// Print heap sizes.
void PrintSizes() const;
// Return amount of memory used and capacity in a space.
intptr_t UsedInWords(Space space) const;
intptr_t CapacityInWords(Space space) const;
+ intptr_t ExternalInWords(Space space) const;
// Return the amount of GCing in microseconds.
int64_t GCTimeInMicros(Space space) const;
« no previous file with comments | « runtime/vm/gc_marker.cc ('k') | runtime/vm/heap.cc » ('j') | no next file with comments »
@@ -162,9 +166,10 @@
// Print heap sizes.
void PrintSizes() const;
- // Return amount of memory used and capacity in a space.
+ // Return amount of memory used and capacity in a space, excluding external.
intptr_t UsedInWords(Space space) const;
intptr_t CapacityInWords(Space space) const;

Powered by Google App Engine
This is Rietveld 408576698